summaryrefslogtreecommitdiffstats
path: root/libkmime/kmime_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkmime/kmime_util.h')
-rw-r--r--libkmime/kmime_util.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkmime/kmime_util.h b/libkmime/kmime_util.h
index e2b3c833..3c710ab7 100644
--- a/libkmime/kmime_util.h
+++ b/libkmime/kmime_util.h
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
/** checks whether @p s contains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {
@@ -167,7 +167,7 @@ namespace KMime {
*/
KDE_EXPORT extern void removeQuots(TQString &str);
/** Converts the given string into a quoted-string if
- the string contains any special characters
+ the string tqcontains any special characters
(ie. one of ()<>@,.;:[]=\").
@param str us-ascii string to work on.
@param forceQuotes if @p true, always add quote characters.
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
- /** checks whether @p s contains any non-us-ascii characters */
+ /** checks whether @p s tqcontains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {